@@ -4,6 +4,11 @@
 #ifndef _AFLIBFFT_H
 #define _AFLIBFFT_H
 
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "aflib.h"
 
 
